==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebPaneDragOverEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPaneDescriptionMetadata } from "./WebDockManagerPaneDescriptionMetadata";
import { WebPaneDragActionDescriptionMetadata } from "./WebPaneDragActionDescriptionMetadata";
import { WebPaneDragOverEventArgsDescription } from "./WebPaneDragOverEventArgsDescription";
/**
 * @hidden
 */
var WebPaneDragOverEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPaneDragOverEventArgsDescriptionMetadata, _super);
    function WebPaneDragOverEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPaneDragOverEventArgsDescriptionMetadata.b = function (a) {
        if (WebPaneDragOverEventArgsDescriptionMetadata.a == null) {
            WebPaneDragOverEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPaneDragOverEventArgsDescriptionMetadata.c(WebPaneDragOverEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebPaneDragOverEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebPaneDragOverEventArgsDescriptionMetadata.a);
        WebDockManagerPaneDescriptionMetadata.d(a);
        WebPaneDragActionDescriptionMetadata.d(a);
    };
    WebPaneDragOverEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PaneDragOverEventArgs");
        a.item("SourcePane", "ExportedType:WebDockManagerPane");
        a.item("Panes", "Collection:WebContentPane:ContentPaneCollection:WebContentPane");
        a.item("Action", "ExportedType:WebPaneDragAction");
        a.item("IsValid", "Boolean");
    };
    WebPaneDragOverEventArgsDescriptionMetadata.d = function (a) {
        WebPaneDragOverEventArgsDescriptionMetadata.b(a);
        a.aa("WebPaneDragOverEventArgs", function () { return new WebPaneDragOverEventArgsDescription(); });
        a.z("WebPaneDragOverEventArgs", WebPaneDragOverEventArgsDescriptionMetadata.a);
    };
    WebPaneDragOverEventArgsDescriptionMetadata.$t = markType(WebPaneDragOverEventArgsDescriptionMetadata, 'WebPaneDragOverEventArgsDescriptionMetadata');
    WebPaneDragOverEventArgsDescriptionMetadata.a = null;
    return WebPaneDragOverEventArgsDescriptionMetadata;
}(Base));
export { WebPaneDragOverEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebPaneDragOverEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPaneDragOverEventArgsDetailDescriptionMetadata } from "./WebPaneDragOverEventArgsDetailDescriptionMetadata";
import { WebPaneDragOverEventArgsDescription } from "./WebPaneDragOverEventArgsDescription";
/**
 * @hidden
 */
var WebPaneDragOverEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPaneDragOverEventArgsDescriptionMetadata, _super);
    function WebPaneDragOverEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPaneDragOverEventArgsDescriptionMetadata.b = function (a) {
        if (WebPaneDragOverEventArgsDescriptionMetadata.a == null) {
            WebPaneDragOverEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPaneDragOverEventArgsDescriptionMetadata.c(WebPaneDragOverEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebPaneDragOverEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebPaneDragOverEventArgsDescriptionMetadata.a);
        WebPaneDragOverEventArgsDetailDescriptionMetadata.d(a);
    };
    WebPaneDragOverEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PaneDragOverEventArgs");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebPaneDragOverEventArgsDetail");
    };
    WebPaneDragOverEventArgsDescriptionMetadata.d = function (a) {
        WebPaneDragOverEventArgsDescriptionMetadata.b(a);
        a.ac("WebPaneDragOverEventArgs", function () { return new WebPaneDragOverEventArgsDescription(); });
        a.ab("WebPaneDragOverEventArgs", WebPaneDragOverEventArgsDescriptionMetadata.a);
    };
    WebPaneDragOverEventArgsDescriptionMetadata.$t = markType(WebPaneDragOverEventArgsDescriptionMetadata, 'WebPaneDragOverEventArgsDescriptionMetadata');
    WebPaneDragOverEventArgsDescriptionMetadata.a = null;
    return WebPaneDragOverEventArgsDescriptionMetadata;
}(Base));
export { WebPaneDragOverEventArgsDescriptionMetadata };
